# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: evochi/v1/evochi.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 27, 2, "", "evochi/v1/evochi.proto")
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16\x65vochi/v1/evochi.proto\x12\tevochi.v1\x1a\x1fgoogle/protobuf/timestamp.proto"#\n\x05Slice\x12\r\n\x05start\x18\x01 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x05">\n\nEvaluation\x12\x1f\n\x05slice\x18\x01 \x01(\x0b\x32\x10.evochi.v1.Slice\x12\x0f\n\x07rewards\x18\x02 \x03(\x02"\x8e\x01\n\nHelloEvent\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x12\n\x05state\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x12\x17\n\x0fpopulation_size\x18\x04 \x01(\x05\x12\x1a\n\x12heartbeat_interval\x18\x05 \x01(\x05\x12\x12\n\nmax_epochs\x18\x06 \x01(\x05\x42\x08\n\x06_state"Q\n\rEvaluateEvent\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\r\n\x05\x65poch\x18\x02 \x01(\x05\x12 \n\x06slices\x18\x03 \x03(\x0b\x32\x10.evochi.v1.Slice"@\n\rOptimizeEvent\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\r\n\x05\x65poch\x18\x02 \x01(\x05\x12\x0f\n\x07rewards\x18\x03 \x03(\x02""\n\x0fInitializeEvent\x12\x0f\n\x07task_id\x18\x01 \x01(\t"1\n\x0fShareStateEvent\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\r\n\x05\x65poch\x18\x02 \x01(\x05"\x1c\n\tStopEvent\x12\x0f\n\x07task_id\x18\x01 \x01(\t"!\n\x10SubscribeRequest\x12\r\n\x05\x63ores\x18\x01 \x01(\x05"\xcf\x02\n\x11SubscribeResponse\x12"\n\x04type\x18\x01 \x01(\x0e\x32\x14.evochi.v1.EventType\x12&\n\x05hello\x18\x02 \x01(\x0b\x32\x15.evochi.v1.HelloEventH\x00\x12,\n\x08\x65valuate\x18\x03 \x01(\x0b\x32\x18.evochi.v1.EvaluateEventH\x00\x12,\n\x08optimize\x18\x04 \x01(\x0b\x32\x18.evochi.v1.OptimizeEventH\x00\x12\x30\n\ninitialize\x18\x05 \x01(\x0b\x32\x1a.evochi.v1.InitializeEventH\x00\x12\x31\n\x0bshare_state\x18\x06 \x01(\x0b\x32\x1a.evochi.v1.ShareStateEventH\x00\x12$\n\x04stop\x18\x07 \x01(\x0b\x32\x14.evochi.v1.StopEventH\x00\x42\x07\n\x05\x65vent"Q\n\x10HeartbeatRequest\x12\x0e\n\x06seq_id\x18\x01 \x01(\x05\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"\x1f\n\x11HeartbeatResponse\x12\n\n\x02ok\x18\x01 \x01(\x08"V\n\x17\x46inishEvaluationRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12*\n\x0b\x65valuations\x18\x02 \x03(\x0b\x32\x15.evochi.v1.Evaluation"&\n\x18\x46inishEvaluationResponse\x12\n\n\x02ok\x18\x01 \x01(\x08",\n\x19\x46inishOptimizationRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t"(\n\x1a\x46inishOptimizationResponse\x12\n\n\x02ok\x18\x01 \x01(\x08"=\n\x1b\x46inishInitializationRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\x0c"*\n\x1c\x46inishInitializationResponse\x12\n\n\x02ok\x18\x01 \x01(\x08"9\n\x17\x46inishShareStateRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\x0c"&\n\x18\x46inishShareStateResponse\x12\n\n\x02ok\x18\x01 \x01(\x08*\xbb\x01\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x45VENT_TYPE_HELLO\x10\x01\x12\x17\n\x13\x45VENT_TYPE_EVALUATE\x10\x03\x12\x17\n\x13\x45VENT_TYPE_OPTIMIZE\x10\x04\x12\x19\n\x15\x45VENT_TYPE_INITIALIZE\x10\x05\x12\x1a\n\x16\x45VENT_TYPE_SHARE_STATE\x10\x06\x12\x13\n\x0f\x45VENT_TYPE_STOP\x10\x07\x32\xb3\x04\n\rEvochiService\x12J\n\tSubscribe\x12\x1b.evochi.v1.SubscribeRequest\x1a\x1c.evochi.v1.SubscribeResponse"\x00\x30\x01\x12H\n\tHeartbeat\x12\x1b.evochi.v1.HeartbeatRequest\x1a\x1c.evochi.v1.HeartbeatResponse"\x00\x12]\n\x10\x46inishEvaluation\x12".evochi.v1.FinishEvaluationRequest\x1a#.evochi.v1.FinishEvaluationResponse"\x00\x12\x63\n\x12\x46inishOptimization\x12$.evochi.v1.FinishOptimizationRequest\x1a%.evochi.v1.FinishOptimizationResponse"\x00\x12i\n\x14\x46inishInitialization\x12&.evochi.v1.FinishInitializationRequest\x1a\'.evochi.v1.FinishInitializationResponse"\x00\x12]\n\x10\x46inishShareState\x12".evochi.v1.FinishShareStateRequest\x1a#.evochi.v1.FinishShareStateResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "evochi.v1.evochi_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_EVENTTYPE"]._serialized_start = 1494
    _globals["_EVENTTYPE"]._serialized_end = 1681
    _globals["_SLICE"]._serialized_start = 70
    _globals["_SLICE"]._serialized_end = 105
    _globals["_EVALUATION"]._serialized_start = 107
    _globals["_EVALUATION"]._serialized_end = 169
    _globals["_HELLOEVENT"]._serialized_start = 172
    _globals["_HELLOEVENT"]._serialized_end = 314
    _globals["_EVALUATEEVENT"]._serialized_start = 316
    _globals["_EVALUATEEVENT"]._serialized_end = 397
    _globals["_OPTIMIZEEVENT"]._serialized_start = 399
    _globals["_OPTIMIZEEVENT"]._serialized_end = 463
    _globals["_INITIALIZEEVENT"]._serialized_start = 465
    _globals["_INITIALIZEEVENT"]._serialized_end = 499
    _globals["_SHARESTATEEVENT"]._serialized_start = 501
    _globals["_SHARESTATEEVENT"]._serialized_end = 550
    _globals["_STOPEVENT"]._serialized_start = 552
    _globals["_STOPEVENT"]._serialized_end = 580
    _globals["_SUBSCRIBEREQUEST"]._serialized_start = 582
    _globals["_SUBSCRIBEREQUEST"]._serialized_end = 615
    _globals["_SUBSCRIBERESPONSE"]._serialized_start = 618
    _globals["_SUBSCRIBERESPONSE"]._serialized_end = 953
    _globals["_HEARTBEATREQUEST"]._serialized_start = 955
    _globals["_HEARTBEATREQUEST"]._serialized_end = 1036
    _globals["_HEARTBEATRESPONSE"]._serialized_start = 1038
    _globals["_HEARTBEATRESPONSE"]._serialized_end = 1069
    _globals["_FINISHEVALUATIONREQUEST"]._serialized_start = 1071
    _globals["_FINISHEVALUATIONREQUEST"]._serialized_end = 1157
    _globals["_FINISHEVALUATIONRESPONSE"]._serialized_start = 1159
    _globals["_FINISHEVALUATIONRESPONSE"]._serialized_end = 1197
    _globals["_FINISHOPTIMIZATIONREQUEST"]._serialized_start = 1199
    _globals["_FINISHOPTIMIZATIONREQUEST"]._serialized_end = 1243
    _globals["_FINISHOPTIMIZATIONRESPONSE"]._serialized_start = 1245
    _globals["_FINISHOPTIMIZATIONRESPONSE"]._serialized_end = 1285
    _globals["_FINISHINITIALIZATIONREQUEST"]._serialized_start = 1287
    _globals["_FINISHINITIALIZATIONREQUEST"]._serialized_end = 1348
    _globals["_FINISHINITIALIZATIONRESPONSE"]._serialized_start = 1350
    _globals["_FINISHINITIALIZATIONRESPONSE"]._serialized_end = 1392
    _globals["_FINISHSHARESTATEREQUEST"]._serialized_start = 1394
    _globals["_FINISHSHARESTATEREQUEST"]._serialized_end = 1451
    _globals["_FINISHSHARESTATERESPONSE"]._serialized_start = 1453
    _globals["_FINISHSHARESTATERESPONSE"]._serialized_end = 1491
    _globals["_EVOCHISERVICE"]._serialized_start = 1684
    _globals["_EVOCHISERVICE"]._serialized_end = 2247
# @@protoc_insertion_point(module_scope)
